@@ -1,4 +1,4 @@
-(defproject prismatic/schema "0.2.1"
+(defproject prismatic/schema "0.2.2"
   :description "Clojure(Script) library for declarative data description and validation"
   :url "http://github.com/prismatic/schema"
   :license {:name "Eclipse Public License"
@@ -27,7 +27,10 @@
                                     :rules :clj}
                                    {:source-paths ["test/cljx"]
                                     :output-path "target/generated/test/cljs"
-                                    :rules :cljs}]}}}
+                                    :rules :cljs}]}}
+             :1.6 {:dependencies [[org.clojure/clojure "1.6.0"]]}}
+
+  :aliases {"all" ["with-profile" "dev:dev,1.6"]}
 
   :jar-exclusions [#"\.cljx|\.swp|\.swo|\.DS_Store"]
 
