@@ -346,12 +346,12 @@
   (-plan->sql [expr]
     (str/join " OR "
               (map
-                #(format "%s %s %s"
-                         (-plan->sql %1)
-                         (:operator expr)
-                         (-plan->sql %2))
-                (maybe-vectorize-string (:column expr))
-                (maybe-vectorize-string (:value expr)))))
+               #(format "%s %s %s"
+                        (-plan->sql %1)
+                        (:operator expr)
+                        (-plan->sql %2))
+               (maybe-vectorize-string (:column expr))
+               (maybe-vectorize-string (:value expr)))))
 
   ArrayBinaryExpression
   (-plan->sql [expr]
@@ -464,7 +464,8 @@
                 [op "res_param_name" param-name]
                 [op "res_param_value" (db-serialize param-value)]]]]]
 
-            [[(op :guard #{"=" "~"}) ["fact" fact-name] (fact-value :guard #(string? %))]]
+            [[(op :guard #{"=" "~"}) ["fact" fact-name] (fact-value :guard #(or (string? %)
+                                                                                (instance? Boolean %)))]]
             ["in" "certname"
              ["extract" "certname"
               ["select-facts"
@@ -472,15 +473,17 @@
                 ["=" "name" fact-name]
                 [op "value" fact-value]]]]]
 
-            [[(op :guard #{"=" ">" "<" "<=" ">="}) ["fact" fact-name] (fact-value :guard #(number? %))]]
-            ["in" "certname"
-             ["extract" "certname"
-              ["select-facts"
-               ["and"
-                ["=" "name" fact-name]
-                ["or"
-                 [op "value_float" fact-value]
-                 [op "value_integer" fact-value]]]]]]
+            [[(op :guard #{"=" ">" "<" "<=" ">="}) ["fact" fact-name] fact-value]]
+            (if-not (number? fact-value)
+              (throw (IllegalArgumentException. (format "Operator '%s' not allowed on value '%s'" op fact-value)))
+              ["in" "certname"
+               ["extract" "certname"
+                ["select-facts"
+                 ["and"
+                  ["=" "name" fact-name]
+                  ["or"
+                   [op "value_float" fact-value]
+                   [op "value_integer" fact-value]]]]]])
 
             [["=" "latest_report?" value]]
             (let [expanded-latest ["in" "report"
@@ -618,7 +621,7 @@
                   (map->BinaryExpression {:operator op
                                           :column ["value_integer" "value_float"]
                                           :value (if (number? value) [value value]
-                                                   (map ks/parse-number [value value]))})
+                                                     (map ks/parse-number [value value]))})
 
                   (map->BinaryExpression {:operator op
                                           :column column
@@ -672,9 +675,9 @@
               [subquery-name & subquery-expression]]]
             (let [columns (maybe-vectorize-string column)]
               (assoc (user-query->logical-obj subquery-name)
-              :project (zipmap columns (repeat (count columns) nil))
-              :where (when (seq subquery-expression)
-                       (user-node->plan-node (user-query->logical-obj subquery-name) (first subquery-expression)))))
+                :project (zipmap columns (repeat (count columns) nil))
+                :where (when (seq subquery-expression)
+                         (user-node->plan-node (user-query->logical-obj subquery-name) (first subquery-expression)))))
             :else nil))
 
 (defn convert-to-plan
@@ -797,7 +800,7 @@
                                   :factsets  [nil
                                               [[:certname :ascending]]])
           to-prepend (filter #(not (= to-dissoc (first %))) order-by)]
-        (assoc paging-options :order-by (concat to-prepend to-append)))))
+      (assoc paging-options :order-by (concat to-prepend to-append)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Public
